@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -14,7 +14,7 @@ namespace tremotesf {
     }
 
     template<typename T>
-    std::string typeName(T&& t) {
+    std::string typeName(const T& t) {
         return impl::demangleTypeName(typeid(t).name());
     }
 }
