@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -16,7 +16,7 @@
 namespace tremotesf {
     namespace {
         constexpr QSettings::Format settingsFormat = [] {
-            if constexpr (isTargetOsWindows) {
+            if constexpr (targetOs == TargetOs::Windows) {
                 return QSettings::IniFormat;
             } else {
                 return QSettings::NativeFormat;
@@ -131,7 +131,8 @@ namespace tremotesf {
         return createTransforming<QVariantList>(torrents, [](const LastTorrents::Torrent& torrent) {
             return QVariantMap{
                 {lastTorrentsHashStringKey, torrent.hashString},
-                {lastTorrentsFinishedKey, torrent.finished}};
+                {lastTorrentsFinishedKey, torrent.finished}
+            };
         });
     }
 
@@ -140,11 +141,12 @@ namespace tremotesf {
         if (var.isValid() && var.type() == QVariant::List) {
             lastTorrents.saved = true;
             lastTorrents.torrents =
-                createTransforming<std::vector<LastTorrents::Torrent>>(var.toList(), [](QVariant&& torrentVar) {
+                createTransforming<std::vector<LastTorrents::Torrent>>(var.toList(), [](const QVariant& torrentVar) {
                     const QVariantMap map = torrentVar.toMap();
                     return LastTorrents::Torrent{
                         map[lastTorrentsHashStringKey].toString(),
-                        map[lastTorrentsFinishedKey].toBool()};
+                        map[lastTorrentsFinishedKey].toBool()
+                    };
                 });
         }
         return lastTorrents;
@@ -223,7 +225,8 @@ namespace tremotesf {
             createTransforming<std::vector<LastTorrents::Torrent>>(rpc->torrents(), [](const auto& torrent) {
                 return LastTorrents::Torrent{
                     .hashString = torrent->data().hashString,
-                    .finished = torrent->data().isFinished()};
+                    .finished = torrent->data().isFinished()
+                };
             });
         mSettings->setValue(lastTorrentsKey, torrents.toVariant());
         mSettings->endGroup();
@@ -410,6 +413,7 @@ namespace tremotesf {
     Servers::Servers(QObject* parent)
         : QObject(parent),
           mSettings(new QSettings(settingsFormat, QSettings::UserScope, qApp->organizationName(), fileName, this)) {
+        mSettings->setFallbacksEnabled(false);
         if (hasServers()) {
             bool setFirst = true;
             const QString current(currentServerName());
@@ -475,11 +479,13 @@ namespace tremotesf {
                 mSettings->value(timeoutKey, 30).toInt(),
 
                 mSettings->value(autoReconnectEnabledKey, false).toBool(),
-                mSettings->value(autoReconnectIntervalKey, 30).toInt()},
+                mSettings->value(autoReconnectIntervalKey, 30).toInt()
+            },
             MountedDirectory::fromVariant(mSettings->value(mountedDirectoriesKey)),
             LastTorrents::fromVariant(mSettings->value(lastTorrentsKey)),
             mSettings->value(lastDownloadDirectoriesKey).toStringList(),
-            mSettings->value(lastDownloadDirectoryKey).toString()};
+            mSettings->value(lastDownloadDirectoryKey).toString()
+        };
         mSettings->endGroup();
         return server;
     }
