@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -6,10 +6,12 @@
 #define TREMOTESF_ADDTORRENTDIALOG_H
 
 #include <QDialog>
+#include "ui/savewindowstatedispatcher.h"
 
 class QCheckBox;
 class QComboBox;
 class QDialogButtonBox;
+class QFormLayout;
 class QGroupBox;
 class QLabel;
 class QLineEdit;
@@ -31,10 +33,23 @@ namespace tremotesf {
         QSize sizeHint() const override;
         void accept() override;
 
+        struct AddTorrentParametersWidgets {
+            TorrentDownloadDirectoryDirectorySelectionWidget* downloadDirectoryWidget;
+            QComboBox* priorityComboBox;
+            QCheckBox* startTorrentCheckBox;
+            QGroupBox* deleteTorrentFileGroupBox;
+            QCheckBox* moveTorrentFileToTrashCheckBox;
+
+            void reset(Rpc* rpc) const;
+            void saveToSettings() const;
+        };
+
+        static AddTorrentParametersWidgets createAddTorrentParametersWidgets(Mode mode, QFormLayout* layout, Rpc* rpc);
+
     private:
-        QString initialDownloadDirectory();
         void setupUi();
         void canAcceptUpdate();
+        void saveState();
 
         Rpc* mRpc;
         QString mUrl;
@@ -43,14 +58,12 @@ namespace tremotesf {
         LocalTorrentFilesModel* mFilesModel{};
 
         QLineEdit* mTorrentLinkLineEdit{};
-        TorrentDownloadDirectoryDirectorySelectionWidget* mDownloadDirectoryWidget{};
         TorrentFilesView* mTorrentFilesView{};
-        QComboBox* mPriorityComboBox{};
-        QCheckBox* mStartTorrentCheckBox{};
-        QGroupBox* mDeleteTorrentFileGroupBox{};
-        QCheckBox* mMoveTorrentFileToTrashCheckBox{};
+        AddTorrentParametersWidgets mAddTorrentParametersWidgets{};
 
         QDialogButtonBox* mDialogButtonBox{};
+
+        SaveWindowStateHandler mSaveStateHandler{this, [this] { saveState(); }};
     };
 }
 
