@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -20,9 +20,12 @@ namespace tremotesf {
         Q_DISABLE_COPY_MOVE(MainWindow)
 
         QSize sizeHint() const override;
-        void showMinimized(bool minimized);
+        void initialShow(bool minimized);
 
     protected:
+        bool event(QEvent* event) override;
+        void showEvent(QShowEvent* event) override;
+        void hideEvent(QHideEvent* event) override;
         void closeEvent(QCloseEvent* event) override;
         void dragEnterEvent(QDragEnterEvent* event) override;
         void dropEvent(QDropEvent* event) override;
