@@ -1,30 +1,37 @@
-// SPDX-FileCopyrightText: 2015-2023 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainwindowstatusbar.h"
 
+#include <QActionGroup>
 #include <QCoreApplication>
 #include <QHBoxLayout>
 #include <QIcon>
 #include <QLabel>
+#include <QMenu>
+#include <QPainter>
+#include <QStyleOption>
 
-#include <KSeparator>
-
+#include "log/log.h"
 #include "rpc/serverstats.h"
 #include "rpc/servers.h"
 #include "rpc/rpc.h"
-#include "utils.h"
+#include "formatutils.h"
 
 namespace tremotesf {
     MainWindowStatusBar::MainWindowStatusBar(const Rpc* rpc, QWidget* parent) : QStatusBar(parent), mRpc(rpc) {
         setSizeGripEnabled(false);
 
+        setContextMenuPolicy(Qt::CustomContextMenu);
+        QObject::connect(this, &QWidget::customContextMenuRequested, this, &MainWindowStatusBar::showContextMenu);
+
         auto container = new QWidget(this);
         addPermanentWidget(container, 1);
 
         auto layout = new QHBoxLayout(container);
-        layout->setContentsMargins(8, 4, 8, 4);
+        // Top/bottom margins are set on mServerLabel below so that they don't affect separators
+        layout->setContentsMargins(8, 0, 8, 0);
 
         mNoServersErrorImage = new QLabel(this);
         mNoServersErrorImage->setPixmap(QIcon::fromTheme("dialog-error"_l1).pixmap(16, 16));
@@ -32,15 +39,16 @@ namespace tremotesf {
         layout->addWidget(mNoServersErrorImage);
 
         mServerLabel = new QLabel(this);
+        mServerLabel->setContentsMargins(0, 5, 0, 5);
         layout->addWidget(mServerLabel);
 
-        mFirstSeparator = new KSeparator(Qt::Vertical, this);
+        mFirstSeparator = new StatusBarSeparator(this);
         layout->addWidget(mFirstSeparator);
 
         mStatusLabel = new QLabel(this);
         layout->addWidget(mStatusLabel);
 
-        mSecondSeparator = new KSeparator(Qt::Vertical, this);
+        mSecondSeparator = new StatusBarSeparator(this);
         layout->addWidget(mSecondSeparator);
 
         mDownloadSpeedImage = new QLabel(this);
@@ -51,7 +59,7 @@ namespace tremotesf {
         mDownloadSpeedLabel = new QLabel(this);
         layout->addWidget(mDownloadSpeedLabel);
 
-        mThirdSeparator = new KSeparator(Qt::Vertical, this);
+        mThirdSeparator = new StatusBarSeparator(this);
         layout->addWidget(mThirdSeparator);
 
         mUploadSpeedImage = new QLabel(this);
@@ -84,8 +92,8 @@ namespace tremotesf {
         QObject::connect(mRpc, &Rpc::statusChanged, this, &MainWindowStatusBar::updateStatusLabels);
 
         QObject::connect(mRpc->serverStats(), &ServerStats::updated, this, [=, this] {
-            mDownloadSpeedLabel->setText(Utils::formatByteSpeed(mRpc->serverStats()->downloadSpeed()));
-            mUploadSpeedLabel->setText(Utils::formatByteSpeed(mRpc->serverStats()->uploadSpeed()));
+            mDownloadSpeedLabel->setText(formatutils::formatByteSpeed(mRpc->serverStats()->downloadSpeed()));
+            mUploadSpeedLabel->setText(formatutils::formatByteSpeed(mRpc->serverStats()->uploadSpeed()));
         });
     }
 
@@ -138,9 +146,68 @@ namespace tremotesf {
     void MainWindowStatusBar::updateStatusLabels() {
         mStatusLabel->setText(mRpc->status().toString());
         if (mRpc->error() != RpcError::NoError) {
-            setToolTip(mRpc->errorMessage());
+            mStatusLabel->setToolTip(mRpc->errorMessage());
         } else {
-            setToolTip({});
+            mStatusLabel->setToolTip({});
         }
     }
+
+    void MainWindowStatusBar::showContextMenu() {
+        auto* const menu = new QMenu(this);
+        auto* const group = new QActionGroup(menu);
+        group->setExclusive(true);
+        menu->setAttribute(Qt::WA_DeleteOnClose, true);
+        const auto servers = Servers::instance()->servers();
+        const auto currentServerName = Servers::instance()->currentServerName();
+        for (const auto& server : servers) {
+            auto* const action = menu->addAction(server.name);
+            action->setCheckable(true);
+            group->addAction(action);
+            if (server.name == currentServerName) {
+                action->setChecked(true);
+            }
+        }
+        menu->addSeparator();
+        auto* const connectionSettingsAction = menu->addAction(
+            QIcon::fromTheme("network-server"_l1),
+            qApp->translate("tremotesf", "&Connection Settings")
+        );
+        QObject::connect(menu, &QMenu::triggered, this, [this, connectionSettingsAction](QAction* action) {
+            if (action == connectionSettingsAction) {
+                emit showConnectionSettingsDialog();
+            } else {
+                const auto selectedName = action->text();
+                const auto servers = Servers::instance()->servers();
+                const auto found = std::find_if(servers.begin(), servers.end(), [&](const auto& server) {
+                    return server.name == selectedName;
+                });
+                if (found != servers.end()) {
+                    Servers::instance()->setCurrentServer(selectedName);
+                } else {
+                    logWarning("Selected server {} which no longer exists", selectedName);
+                }
+            }
+        });
+        menu->popup(QCursor::pos());
+    }
+
+    StatusBarSeparator::StatusBarSeparator(QWidget* parent) : QWidget(parent) {
+        setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+    }
+
+    QSize StatusBarSeparator::sizeHint() const {
+        QStyleOption opt{};
+        opt.initFrom(this);
+        opt.state.setFlag(QStyle::State_Horizontal);
+        const int extent = style()->pixelMetric(QStyle::PM_ToolBarSeparatorExtent, &opt, this);
+        return {extent, extent};
+    }
+
+    void StatusBarSeparator::paintEvent(QPaintEvent*) {
+        QPainter p(this);
+        QStyleOption opt{};
+        opt.initFrom(this);
+        opt.state.setFlag(QStyle::State_Horizontal);
+        style()->drawPrimitive(QStyle::PE_IndicatorToolBarSeparator, &opt, &p, this);
+    }
 }
